# -*- coding: utf-8 -*-
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stellarstation/api/v1/transport.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from stellarstation.api.v1.monitoring import monitoring_pb2 as stellarstation_dot_api_dot_v1_dot_monitoring_dot_monitoring__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='stellarstation/api/v1/transport.proto',
  package='stellarstation.api.v1',
  syntax='proto3',
  serialized_options=_b('\n\031com.stellarstation.api.v1B\016TransportProtoP\001Z2github.com/infostellarinc/go-stellarstation/api/v1'),
  serialized_pb=_b('\n%stellarstation/api/v1/transport.proto\x12\x15stellarstation.api.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31stellarstation/api/v1/monitoring/monitoring.proto\"\xfa\x01\n\tTelemetry\x12/\n\x07\x66raming\x18\x01 \x01(\x0e\x32\x1e.stellarstation.api.v1.Framing\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x1d\n\x15\x64ownlink_frequency_hz\x18\x03 \x01(\x04\x12<\n\x18time_first_byte_received\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12;\n\x17time_last_byte_received\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0c\x66rame_header\x18\x06 \x01(\x0c\"\xf0\x01\n\x0bStreamEvent\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12W\n\x0c\x63ommand_sent\x18\x02 \x01(\x0b\x32?.stellarstation.api.v1.StreamEvent.CommandSentFromGroundStationH\x00\x12K\n\x15plan_monitoring_event\x18\x03 \x01(\x0b\x32*.stellarstation.api.v1.PlanMonitoringEventH\x00\x1a\x1e\n\x1c\x43ommandSentFromGroundStationB\x07\n\x05\x45vent\"\xc0\x02\n\x13PlanMonitoringEvent\x12\x0f\n\x07plan_id\x18\x01 \x01(\t\x12\x64\n\x1cground_station_configuration\x18\x02 \x01(\x0b\x32<.stellarstation.api.v1.monitoring.GroundStationConfigurationH\x00\x12T\n\x14ground_station_state\x18\x03 \x01(\x0b\x32\x34.stellarstation.api.v1.monitoring.GroundStationStateH\x00\x12T\n\x14ground_station_event\x18\x04 \x01(\x0b\x32\x34.stellarstation.api.v1.monitoring.GroundStationEventH\x00\x42\x06\n\x04Info*l\n\x07\x46raming\x12\r\n\tBITSTREAM\x10\x00\x12\x08\n\x04\x41X25\x10\x01\x12\x06\n\x02IQ\x10\x02\x12\r\n\tIMAGE_PNG\x10\x03\x12\x0e\n\nIMAGE_JPEG\x10\x04\x12\x12\n\x0e\x46REE_TEXT_UTF8\x10\x05\x12\r\n\tWATERFALL\x10\x06\x42\x61\n\x19\x63om.stellarstation.api.v1B\x0eTransportProtoP\x01Z2github.com/infostellarinc/go-stellarstation/api/v1b\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,stellarstation_dot_api_dot_v1_dot_monitoring_dot_monitoring__pb2.DESCRIPTOR,])

_FRAMING = _descriptor.EnumDescriptor(
  name='Framing',
  full_name='stellarstation.api.v1.Framing',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BITSTREAM', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AX25', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IQ', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IMAGE_PNG', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IMAGE_JPEG', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FREE_TEXT_UTF8', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WATERFALL', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=967,
  serialized_end=1075,
)
_sym_db.RegisterEnumDescriptor(_FRAMING)

Framing = enum_type_wrapper.EnumTypeWrapper(_FRAMING)
BITSTREAM = 0
AX25 = 1
IQ = 2
IMAGE_PNG = 3
IMAGE_JPEG = 4
FREE_TEXT_UTF8 = 5
WATERFALL = 6



_TELEMETRY = _descriptor.Descriptor(
  name='Telemetry',
  full_name='stellarstation.api.v1.Telemetry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='framing', full_name='stellarstation.api.v1.Telemetry.framing', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='stellarstation.api.v1.Telemetry.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='downlink_frequency_hz', full_name='stellarstation.api.v1.Telemetry.downlink_frequency_hz', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_first_byte_received', full_name='stellarstation.api.v1.Telemetry.time_first_byte_received', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_last_byte_received', full_name='stellarstation.api.v1.Telemetry.time_last_byte_received', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frame_header', full_name='stellarstation.api.v1.Telemetry.frame_header', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=149,
  serialized_end=399,
)


_STREAMEVENT_COMMANDSENTFROMGROUNDSTATION = _descriptor.Descriptor(
  name='CommandSentFromGroundStation',
  full_name='stellarstation.api.v1.StreamEvent.CommandSentFromGroundStation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=603,
  serialized_end=633,
)

_STREAMEVENT = _descriptor.Descriptor(
  name='StreamEvent',
  full_name='stellarstation.api.v1.StreamEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_id', full_name='stellarstation.api.v1.StreamEvent.request_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='command_sent', full_name='stellarstation.api.v1.StreamEvent.command_sent', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plan_monitoring_event', full_name='stellarstation.api.v1.StreamEvent.plan_monitoring_event', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STREAMEVENT_COMMANDSENTFROMGROUNDSTATION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Event', full_name='stellarstation.api.v1.StreamEvent.Event',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=402,
  serialized_end=642,
)


_PLANMONITORINGEVENT = _descriptor.Descriptor(
  name='PlanMonitoringEvent',
  full_name='stellarstation.api.v1.PlanMonitoringEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='plan_id', full_name='stellarstation.api.v1.PlanMonitoringEvent.plan_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ground_station_configuration', full_name='stellarstation.api.v1.PlanMonitoringEvent.ground_station_configuration', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ground_station_state', full_name='stellarstation.api.v1.PlanMonitoringEvent.ground_station_state', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ground_station_event', full_name='stellarstation.api.v1.PlanMonitoringEvent.ground_station_event', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Info', full_name='stellarstation.api.v1.PlanMonitoringEvent.Info',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=645,
  serialized_end=965,
)

_TELEMETRY.fields_by_name['framing'].enum_type = _FRAMING
_TELEMETRY.fields_by_name['time_first_byte_received'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TELEMETRY.fields_by_name['time_last_byte_received'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMEVENT_COMMANDSENTFROMGROUNDSTATION.containing_type = _STREAMEVENT
_STREAMEVENT.fields_by_name['command_sent'].message_type = _STREAMEVENT_COMMANDSENTFROMGROUNDSTATION
_STREAMEVENT.fields_by_name['plan_monitoring_event'].message_type = _PLANMONITORINGEVENT
_STREAMEVENT.oneofs_by_name['Event'].fields.append(
  _STREAMEVENT.fields_by_name['command_sent'])
_STREAMEVENT.fields_by_name['command_sent'].containing_oneof = _STREAMEVENT.oneofs_by_name['Event']
_STREAMEVENT.oneofs_by_name['Event'].fields.append(
  _STREAMEVENT.fields_by_name['plan_monitoring_event'])
_STREAMEVENT.fields_by_name['plan_monitoring_event'].containing_oneof = _STREAMEVENT.oneofs_by_name['Event']
_PLANMONITORINGEVENT.fields_by_name['ground_station_configuration'].message_type = stellarstation_dot_api_dot_v1_dot_monitoring_dot_monitoring__pb2._GROUNDSTATIONCONFIGURATION
_PLANMONITORINGEVENT.fields_by_name['ground_station_state'].message_type = stellarstation_dot_api_dot_v1_dot_monitoring_dot_monitoring__pb2._GROUNDSTATIONSTATE
_PLANMONITORINGEVENT.fields_by_name['ground_station_event'].message_type = stellarstation_dot_api_dot_v1_dot_monitoring_dot_monitoring__pb2._GROUNDSTATIONEVENT
_PLANMONITORINGEVENT.oneofs_by_name['Info'].fields.append(
  _PLANMONITORINGEVENT.fields_by_name['ground_station_configuration'])
_PLANMONITORINGEVENT.fields_by_name['ground_station_configuration'].containing_oneof = _PLANMONITORINGEVENT.oneofs_by_name['Info']
_PLANMONITORINGEVENT.oneofs_by_name['Info'].fields.append(
  _PLANMONITORINGEVENT.fields_by_name['ground_station_state'])
_PLANMONITORINGEVENT.fields_by_name['ground_station_state'].containing_oneof = _PLANMONITORINGEVENT.oneofs_by_name['Info']
_PLANMONITORINGEVENT.oneofs_by_name['Info'].fields.append(
  _PLANMONITORINGEVENT.fields_by_name['ground_station_event'])
_PLANMONITORINGEVENT.fields_by_name['ground_station_event'].containing_oneof = _PLANMONITORINGEVENT.oneofs_by_name['Info']
DESCRIPTOR.message_types_by_name['Telemetry'] = _TELEMETRY
DESCRIPTOR.message_types_by_name['StreamEvent'] = _STREAMEVENT
DESCRIPTOR.message_types_by_name['PlanMonitoringEvent'] = _PLANMONITORINGEVENT
DESCRIPTOR.enum_types_by_name['Framing'] = _FRAMING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Telemetry = _reflection.GeneratedProtocolMessageType('Telemetry', (_message.Message,), dict(
  DESCRIPTOR = _TELEMETRY,
  __module__ = 'stellarstation.api.v1.transport_pb2'
  ,
  __doc__ = """A chunk or frame of telemetry data that has been received from a
  satellite.
  
  
  Attributes:
      framing:
          The framing of this telemetry data. If ``RAW``, this telemetry
          will be an arbitrarily sized chunk of the bitstream.
      data:
          The payload of this telemetry.
      downlink_frequency_hz:
          The actual downlink frequency, in Hz, used when receiving
          ``data``, including adjustments for doppler shift.
      time_first_byte_received:
          Timestamp when the first byte of ``data`` was received.
      time_last_byte_received:
          Timestamp when the last byte of ``data`` was received.
      frame_header:
          The binary header of the telemetry frame, if ``framing`` is
          not ``RAW``.  -  AX25 - This is either Address + Control, or
          Address + Control + PID.    The checksum is not returned.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.Telemetry)
  ))
_sym_db.RegisterMessage(Telemetry)

StreamEvent = _reflection.GeneratedProtocolMessageType('StreamEvent', (_message.Message,), dict(

  CommandSentFromGroundStation = _reflection.GeneratedProtocolMessageType('CommandSentFromGroundStation', (_message.Message,), dict(
    DESCRIPTOR = _STREAMEVENT_COMMANDSENTFROMGROUNDSTATION,
    __module__ = 'stellarstation.api.v1.transport_pb2'
    ,
    __doc__ = """An event indicating the commands in the request were sent by the ground
    station through its radio.
    
    Empty, may be extended in the future.
    """,
    # @@protoc_insertion_point(class_scope:stellarstation.api.v1.StreamEvent.CommandSentFromGroundStation)
    ))
  ,
  DESCRIPTOR = _STREAMEVENT,
  __module__ = 'stellarstation.api.v1.transport_pb2'
  ,
  __doc__ = """A stream event payload.
  
  
  Attributes:
      request_id:
          The ID of the request this event corresponds to, copied from
          ``SatelliteStreamRequest.request_id`` when present. If the
          event doesn’t correspond to a request, this is always empty.
      command_sent:
          An event indicating the commands in the request were sent by
          the ground station through its radio.
      plan_monitoring_event:
          An event with monitoring information for a particular executed
          plan.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.StreamEvent)
  ))
_sym_db.RegisterMessage(StreamEvent)
_sym_db.RegisterMessage(StreamEvent.CommandSentFromGroundStation)

PlanMonitoringEvent = _reflection.GeneratedProtocolMessageType('PlanMonitoringEvent', (_message.Message,), dict(
  DESCRIPTOR = _PLANMONITORINGEVENT,
  __module__ = 'stellarstation.api.v1.transport_pb2'
  ,
  __doc__ = """A monitoring event that occurred during the execution of the plan.
  Information about the current configuration of the ground station and
  state of components is returned to provide information that can help to
  troubleshoot issues with the plan.
  
  
  Attributes:
      plan_id:
          The ID of the plan being monitored.
      ground_station_configuration:
          Information about the current configuration of the ground
          station when beginning to execute a plan. This will only be
          returned once at the beginning of execution. Information that
          is provided by the ground station executing the plan will be
          returned - any fields that are not supported by the ground
          station will be left unfilled.
      ground_station_state:
          Information about the current state of the ground station
          while executing a plan. This will be returned periodically
          during execution of the plan. Information that is provided by
          the ground station executing the plan will be returned - any
          fields that are not supported by the ground station will be
          left unfilled.
      ground_station_event:
          Information about events generated by the ground station while
          executing a plan.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.PlanMonitoringEvent)
  ))
_sym_db.RegisterMessage(PlanMonitoringEvent)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
