# -*- coding: utf-8 -*-
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stellarstation/api/v1/groundstation/groundstation.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from stellarstation.api.v1.radio import radio_pb2 as stellarstation_dot_api_dot_v1_dot_radio_dot_radio__pb2
from stellarstation.api.v1 import transport_pb2 as stellarstation_dot_api_dot_v1_dot_transport__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='stellarstation/api/v1/groundstation/groundstation.proto',
  package='stellarstation.api.v1.groundstation',
  syntax='proto3',
  serialized_options=_b('\n\'com.stellarstation.api.v1.groundstationB\022GroundStationProtoP\001Z@github.com/infostellarinc/go-stellarstation/api/v1/groundstation'),
  serialized_pb=_b('\n7stellarstation/api/v1/groundstation/groundstation.proto\x12#stellarstation.api.v1.groundstation\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\'stellarstation/api/v1/radio/radio.proto\x1a%stellarstation/api/v1/transport.proto\"\x8c\x01\n\x10ListPlansRequest\x12\x19\n\x11ground_station_id\x18\x01 \x01(\t\x12-\n\taos_after\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\naos_before\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"L\n\x11ListPlansResponse\x12\x37\n\x04plan\x18\x01 \x03(\x0b\x32).stellarstation.api.v1.groundstation.Plan\"\xb2\x03\n\x04Plan\x12\x0f\n\x07plan_id\x18\x01 \x01(\t\x12\x35\n\x03tle\x18\x02 \x01(\x0b\x32(.stellarstation.api.v1.groundstation.Tle\x12.\n\nstart_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x61os_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08los_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12T\n\x15\x64ownlink_radio_device\x18\x05 \x01(\x0b\x32\x35.stellarstation.api.v1.radio.RadioDeviceConfiguration\x12R\n\x13uplink_radio_device\x18\x06 \x01(\x0b\x32\x35.stellarstation.api.v1.radio.RadioDeviceConfiguration\"%\n\x03Tle\x12\x0e\n\x06line_1\x18\x01 \x01(\t\x12\x0e\n\x06line_2\x18\x02 \x01(\t\"\x87\x01\n\x14UnavailabilityWindow\x12\x11\n\twindow_id\x18\x01 \x01(\t\x12.\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x9b\x01\n ListUnavailabilityWindowsRequest\x12\x19\n\x11ground_station_id\x18\x01 \x01(\t\x12.\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"n\n!ListUnavailabilityWindowsResponse\x12I\n\x06window\x18\x01 \x03(\x0b\x32\x39.stellarstation.api.v1.groundstation.UnavailabilityWindow\"\x99\x01\n\x1e\x41\x64\x64UnavailabilityWindowRequest\x12\x19\n\x11ground_station_id\x18\x01 \x01(\t\x12.\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"4\n\x1f\x41\x64\x64UnavailabilityWindowResponse\x12\x11\n\twindow_id\x18\x01 \x01(\t\"6\n!DeleteUnavailabilityWindowRequest\x12\x11\n\twindow_id\x18\x01 \x01(\t\"$\n\"DeleteUnavailabilityWindowResponse\"\xea\x01\n\x1aGroundStationStreamRequest\x12\x19\n\x11ground_station_id\x18\x01 \x01(\t\x12\x12\n\nstream_tag\x18\x02 \x01(\t\x12V\n\x13satellite_telemetry\x18\x03 \x01(\x0b\x32\x37.stellarstation.api.v1.groundstation.SatelliteTelemetryH\x00\x12:\n\x0cstream_event\x18\x04 \x01(\x0b\x32\".stellarstation.api.v1.StreamEventH\x00\x42\t\n\x07Request\"Z\n\x12SatelliteTelemetry\x12\x0f\n\x07plan_id\x18\x01 \x01(\t\x12\x33\n\ttelemetry\x18\x02 \x01(\x0b\x32 .stellarstation.api.v1.Telemetry\"\xa5\x01\n\x1bGroundStationStreamResponse\x12\x0f\n\x07plan_id\x18\x01 \x01(\t\x12\x13\n\x0bresponse_id\x18\x02 \x01(\t\x12T\n\x12satellite_commands\x18\x03 \x01(\x0b\x32\x36.stellarstation.api.v1.groundstation.SatelliteCommandsH\x00\x42\n\n\x08Response\"$\n\x11SatelliteCommands\x12\x0f\n\x07\x63ommand\x18\x01 \x03(\x0c\x32\xb9\x06\n\x14GroundStationService\x12\xa4\x01\n\x17\x41\x64\x64UnavailabilityWindow\x12\x43.stellarstation.api.v1.groundstation.AddUnavailabilityWindowRequest\x1a\x44.stellarstation.api.v1.groundstation.AddUnavailabilityWindowResponse\x12\xad\x01\n\x1a\x44\x65leteUnavailabilityWindow\x12\x46.stellarstation.api.v1.groundstation.DeleteUnavailabilityWindowRequest\x1aG.stellarstation.api.v1.groundstation.DeleteUnavailabilityWindowResponse\x12z\n\tListPlans\x12\x35.stellarstation.api.v1.groundstation.ListPlansRequest\x1a\x36.stellarstation.api.v1.groundstation.ListPlansResponse\x12\xaa\x01\n\x19ListUnavailabilityWindows\x12\x45.stellarstation.api.v1.groundstation.ListUnavailabilityWindowsRequest\x1a\x46.stellarstation.api.v1.groundstation.ListUnavailabilityWindowsResponse\x12\xa0\x01\n\x17OpenGroundStationStream\x12?.stellarstation.api.v1.groundstation.GroundStationStreamRequest\x1a@.stellarstation.api.v1.groundstation.GroundStationStreamResponse(\x01\x30\x01\x42\x81\x01\n\'com.stellarstation.api.v1.groundstationB\x12GroundStationProtoP\x01Z@github.com/infostellarinc/go-stellarstation/api/v1/groundstationb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,stellarstation_dot_api_dot_v1_dot_radio_dot_radio__pb2.DESCRIPTOR,stellarstation_dot_api_dot_v1_dot_transport__pb2.DESCRIPTOR,])




_LISTPLANSREQUEST = _descriptor.Descriptor(
  name='ListPlansRequest',
  full_name='stellarstation.api.v1.groundstation.ListPlansRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ground_station_id', full_name='stellarstation.api.v1.groundstation.ListPlansRequest.ground_station_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aos_after', full_name='stellarstation.api.v1.groundstation.ListPlansRequest.aos_after', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aos_before', full_name='stellarstation.api.v1.groundstation.ListPlansRequest.aos_before', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=210,
  serialized_end=350,
)


_LISTPLANSRESPONSE = _descriptor.Descriptor(
  name='ListPlansResponse',
  full_name='stellarstation.api.v1.groundstation.ListPlansResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='plan', full_name='stellarstation.api.v1.groundstation.ListPlansResponse.plan', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=352,
  serialized_end=428,
)


_PLAN = _descriptor.Descriptor(
  name='Plan',
  full_name='stellarstation.api.v1.groundstation.Plan',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='plan_id', full_name='stellarstation.api.v1.groundstation.Plan.plan_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tle', full_name='stellarstation.api.v1.groundstation.Plan.tle', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='stellarstation.api.v1.groundstation.Plan.start_time', index=2,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='stellarstation.api.v1.groundstation.Plan.end_time', index=3,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aos_time', full_name='stellarstation.api.v1.groundstation.Plan.aos_time', index=4,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='los_time', full_name='stellarstation.api.v1.groundstation.Plan.los_time', index=5,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='downlink_radio_device', full_name='stellarstation.api.v1.groundstation.Plan.downlink_radio_device', index=6,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uplink_radio_device', full_name='stellarstation.api.v1.groundstation.Plan.uplink_radio_device', index=7,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=431,
  serialized_end=865,
)


_TLE = _descriptor.Descriptor(
  name='Tle',
  full_name='stellarstation.api.v1.groundstation.Tle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='line_1', full_name='stellarstation.api.v1.groundstation.Tle.line_1', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_2', full_name='stellarstation.api.v1.groundstation.Tle.line_2', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=867,
  serialized_end=904,
)


_UNAVAILABILITYWINDOW = _descriptor.Descriptor(
  name='UnavailabilityWindow',
  full_name='stellarstation.api.v1.groundstation.UnavailabilityWindow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='window_id', full_name='stellarstation.api.v1.groundstation.UnavailabilityWindow.window_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='stellarstation.api.v1.groundstation.UnavailabilityWindow.start_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='stellarstation.api.v1.groundstation.UnavailabilityWindow.end_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=907,
  serialized_end=1042,
)


_LISTUNAVAILABILITYWINDOWSREQUEST = _descriptor.Descriptor(
  name='ListUnavailabilityWindowsRequest',
  full_name='stellarstation.api.v1.groundstation.ListUnavailabilityWindowsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ground_station_id', full_name='stellarstation.api.v1.groundstation.ListUnavailabilityWindowsRequest.ground_station_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='stellarstation.api.v1.groundstation.ListUnavailabilityWindowsRequest.start_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='stellarstation.api.v1.groundstation.ListUnavailabilityWindowsRequest.end_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1045,
  serialized_end=1200,
)


_LISTUNAVAILABILITYWINDOWSRESPONSE = _descriptor.Descriptor(
  name='ListUnavailabilityWindowsResponse',
  full_name='stellarstation.api.v1.groundstation.ListUnavailabilityWindowsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='window', full_name='stellarstation.api.v1.groundstation.ListUnavailabilityWindowsResponse.window', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1202,
  serialized_end=1312,
)


_ADDUNAVAILABILITYWINDOWREQUEST = _descriptor.Descriptor(
  name='AddUnavailabilityWindowRequest',
  full_name='stellarstation.api.v1.groundstation.AddUnavailabilityWindowRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ground_station_id', full_name='stellarstation.api.v1.groundstation.AddUnavailabilityWindowRequest.ground_station_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='stellarstation.api.v1.groundstation.AddUnavailabilityWindowRequest.start_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='stellarstation.api.v1.groundstation.AddUnavailabilityWindowRequest.end_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1315,
  serialized_end=1468,
)


_ADDUNAVAILABILITYWINDOWRESPONSE = _descriptor.Descriptor(
  name='AddUnavailabilityWindowResponse',
  full_name='stellarstation.api.v1.groundstation.AddUnavailabilityWindowResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='window_id', full_name='stellarstation.api.v1.groundstation.AddUnavailabilityWindowResponse.window_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1470,
  serialized_end=1522,
)


_DELETEUNAVAILABILITYWINDOWREQUEST = _descriptor.Descriptor(
  name='DeleteUnavailabilityWindowRequest',
  full_name='stellarstation.api.v1.groundstation.DeleteUnavailabilityWindowRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='window_id', full_name='stellarstation.api.v1.groundstation.DeleteUnavailabilityWindowRequest.window_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1524,
  serialized_end=1578,
)


_DELETEUNAVAILABILITYWINDOWRESPONSE = _descriptor.Descriptor(
  name='DeleteUnavailabilityWindowResponse',
  full_name='stellarstation.api.v1.groundstation.DeleteUnavailabilityWindowResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1580,
  serialized_end=1616,
)


_GROUNDSTATIONSTREAMREQUEST = _descriptor.Descriptor(
  name='GroundStationStreamRequest',
  full_name='stellarstation.api.v1.groundstation.GroundStationStreamRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ground_station_id', full_name='stellarstation.api.v1.groundstation.GroundStationStreamRequest.ground_station_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stream_tag', full_name='stellarstation.api.v1.groundstation.GroundStationStreamRequest.stream_tag', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='satellite_telemetry', full_name='stellarstation.api.v1.groundstation.GroundStationStreamRequest.satellite_telemetry', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stream_event', full_name='stellarstation.api.v1.groundstation.GroundStationStreamRequest.stream_event', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Request', full_name='stellarstation.api.v1.groundstation.GroundStationStreamRequest.Request',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1619,
  serialized_end=1853,
)


_SATELLITETELEMETRY = _descriptor.Descriptor(
  name='SatelliteTelemetry',
  full_name='stellarstation.api.v1.groundstation.SatelliteTelemetry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='plan_id', full_name='stellarstation.api.v1.groundstation.SatelliteTelemetry.plan_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='telemetry', full_name='stellarstation.api.v1.groundstation.SatelliteTelemetry.telemetry', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1855,
  serialized_end=1945,
)


_GROUNDSTATIONSTREAMRESPONSE = _descriptor.Descriptor(
  name='GroundStationStreamResponse',
  full_name='stellarstation.api.v1.groundstation.GroundStationStreamResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='plan_id', full_name='stellarstation.api.v1.groundstation.GroundStationStreamResponse.plan_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='response_id', full_name='stellarstation.api.v1.groundstation.GroundStationStreamResponse.response_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='satellite_commands', full_name='stellarstation.api.v1.groundstation.GroundStationStreamResponse.satellite_commands', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Response', full_name='stellarstation.api.v1.groundstation.GroundStationStreamResponse.Response',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1948,
  serialized_end=2113,
)


_SATELLITECOMMANDS = _descriptor.Descriptor(
  name='SatelliteCommands',
  full_name='stellarstation.api.v1.groundstation.SatelliteCommands',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='stellarstation.api.v1.groundstation.SatelliteCommands.command', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2115,
  serialized_end=2151,
)

_LISTPLANSREQUEST.fields_by_name['aos_after'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPLANSREQUEST.fields_by_name['aos_before'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPLANSRESPONSE.fields_by_name['plan'].message_type = _PLAN
_PLAN.fields_by_name['tle'].message_type = _TLE
_PLAN.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PLAN.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PLAN.fields_by_name['aos_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PLAN.fields_by_name['los_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PLAN.fields_by_name['downlink_radio_device'].message_type = stellarstation_dot_api_dot_v1_dot_radio_dot_radio__pb2._RADIODEVICECONFIGURATION
_PLAN.fields_by_name['uplink_radio_device'].message_type = stellarstation_dot_api_dot_v1_dot_radio_dot_radio__pb2._RADIODEVICECONFIGURATION
_UNAVAILABILITYWINDOW.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_UNAVAILABILITYWINDOW.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTUNAVAILABILITYWINDOWSREQUEST.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTUNAVAILABILITYWINDOWSREQUEST.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTUNAVAILABILITYWINDOWSRESPONSE.fields_by_name['window'].message_type = _UNAVAILABILITYWINDOW
_ADDUNAVAILABILITYWINDOWREQUEST.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ADDUNAVAILABILITYWINDOWREQUEST.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GROUNDSTATIONSTREAMREQUEST.fields_by_name['satellite_telemetry'].message_type = _SATELLITETELEMETRY
_GROUNDSTATIONSTREAMREQUEST.fields_by_name['stream_event'].message_type = stellarstation_dot_api_dot_v1_dot_transport__pb2._STREAMEVENT
_GROUNDSTATIONSTREAMREQUEST.oneofs_by_name['Request'].fields.append(
  _GROUNDSTATIONSTREAMREQUEST.fields_by_name['satellite_telemetry'])
_GROUNDSTATIONSTREAMREQUEST.fields_by_name['satellite_telemetry'].containing_oneof = _GROUNDSTATIONSTREAMREQUEST.oneofs_by_name['Request']
_GROUNDSTATIONSTREAMREQUEST.oneofs_by_name['Request'].fields.append(
  _GROUNDSTATIONSTREAMREQUEST.fields_by_name['stream_event'])
_GROUNDSTATIONSTREAMREQUEST.fields_by_name['stream_event'].containing_oneof = _GROUNDSTATIONSTREAMREQUEST.oneofs_by_name['Request']
_SATELLITETELEMETRY.fields_by_name['telemetry'].message_type = stellarstation_dot_api_dot_v1_dot_transport__pb2._TELEMETRY
_GROUNDSTATIONSTREAMRESPONSE.fields_by_name['satellite_commands'].message_type = _SATELLITECOMMANDS
_GROUNDSTATIONSTREAMRESPONSE.oneofs_by_name['Response'].fields.append(
  _GROUNDSTATIONSTREAMRESPONSE.fields_by_name['satellite_commands'])
_GROUNDSTATIONSTREAMRESPONSE.fields_by_name['satellite_commands'].containing_oneof = _GROUNDSTATIONSTREAMRESPONSE.oneofs_by_name['Response']
DESCRIPTOR.message_types_by_name['ListPlansRequest'] = _LISTPLANSREQUEST
DESCRIPTOR.message_types_by_name['ListPlansResponse'] = _LISTPLANSRESPONSE
DESCRIPTOR.message_types_by_name['Plan'] = _PLAN
DESCRIPTOR.message_types_by_name['Tle'] = _TLE
DESCRIPTOR.message_types_by_name['UnavailabilityWindow'] = _UNAVAILABILITYWINDOW
DESCRIPTOR.message_types_by_name['ListUnavailabilityWindowsRequest'] = _LISTUNAVAILABILITYWINDOWSREQUEST
DESCRIPTOR.message_types_by_name['ListUnavailabilityWindowsResponse'] = _LISTUNAVAILABILITYWINDOWSRESPONSE
DESCRIPTOR.message_types_by_name['AddUnavailabilityWindowRequest'] = _ADDUNAVAILABILITYWINDOWREQUEST
DESCRIPTOR.message_types_by_name['AddUnavailabilityWindowResponse'] = _ADDUNAVAILABILITYWINDOWRESPONSE
DESCRIPTOR.message_types_by_name['DeleteUnavailabilityWindowRequest'] = _DELETEUNAVAILABILITYWINDOWREQUEST
DESCRIPTOR.message_types_by_name['DeleteUnavailabilityWindowResponse'] = _DELETEUNAVAILABILITYWINDOWRESPONSE
DESCRIPTOR.message_types_by_name['GroundStationStreamRequest'] = _GROUNDSTATIONSTREAMREQUEST
DESCRIPTOR.message_types_by_name['SatelliteTelemetry'] = _SATELLITETELEMETRY
DESCRIPTOR.message_types_by_name['GroundStationStreamResponse'] = _GROUNDSTATIONSTREAMRESPONSE
DESCRIPTOR.message_types_by_name['SatelliteCommands'] = _SATELLITECOMMANDS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListPlansRequest = _reflection.GeneratedProtocolMessageType('ListPlansRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTPLANSREQUEST,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  ,
  __doc__ = """Request for the ``ListPlans`` method.
  
  
  Attributes:
      ground_station_id:
          The ID of the ground station to list plans for. The ID can be
          found on the StellarStation Console page for the ground
          station.
      aos_after:
          The start time of the range of plans to list (inclusive). Only
          plans with an Acquisition of Signal (AOS) at or after this
          time will be returned. It is an error for the duration between
          ``aos_after`` and ``aos_before`` to be longer than 31 days.
      aos_before:
          The end time of the range of plans to list (exclusive). Only
          plans with an Acquisition of Signal (AOS) before this time
          will be returned. It is an error for the duration between
          ``aos_after`` and ``aos_before`` to be longer than 31 days.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.ListPlansRequest)
  ))
_sym_db.RegisterMessage(ListPlansRequest)

ListPlansResponse = _reflection.GeneratedProtocolMessageType('ListPlansResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTPLANSRESPONSE,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  ,
  __doc__ = """A response from the ``ListPlans`` method.
  
  
  Attributes:
      plan:
          The requested list of plans for the ground station.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.ListPlansResponse)
  ))
_sym_db.RegisterMessage(ListPlansResponse)

Plan = _reflection.GeneratedProtocolMessageType('Plan', (_message.Message,), dict(
  DESCRIPTOR = _PLAN,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  ,
  __doc__ = """A scheduled pass. The plan will be executed on its ground station to
  communicate with its satellite during a time range between AOS and LOS,
  unless explicitly cancelled.
  
  Next ID: 9
  
  
  Attributes:
      plan_id:
          The ID of this plan.
      tle:
          The TLE for the satellite in this plan.
      start_time:
          The start of the time window reserved for the plan.  This
          timestamp does not change over time, and is set to allow
          sufficient time at the start of a plan to allow the ground
          station to prepare for plan execution.
      end_time:
          The end of the time window reserved for the plan.  This
          timestamp does not change over time, and is set to allow
          sufficient time at the end of a plan to allow the ground
          station to perform cleanup tasks after executing the plan.
      aos_time:
          The time of AOS between the ground station and satellite in
          this plan.  This timestamp will never be before ‘start_time’.
          If may change over time (for example, if updated TLE becomes
          available).
      los_time:
          The time of LOS between the ground station and satellite in
          this plan.  This timestamp will never be after ‘end_time’. If
          may change over time (for example, if updated TLE becomes
          available).
      downlink_radio_device:
          Configuration of the radio device used for downlinking from
          the satellite. Ground stations will need to configure
          reception during the plan to match this device.
      uplink_radio_device:
          Configuration of the radio device used for uplinking to the
          satellite. Ground stations will need to configure transmission
          during the plan to match this device.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.Plan)
  ))
_sym_db.RegisterMessage(Plan)

Tle = _reflection.GeneratedProtocolMessageType('Tle', (_message.Message,), dict(
  DESCRIPTOR = _TLE,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  ,
  __doc__ = """Unparsed TLE data for a satellite -
  https://en.wikipedia.org/wiki/Two-line_element_set
  
  
  Attributes:
      line_1:
          The first line of the TLE. Not a title line.
      line_2:
          The second line of the TLE.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.Tle)
  ))
_sym_db.RegisterMessage(Tle)

UnavailabilityWindow = _reflection.GeneratedProtocolMessageType('UnavailabilityWindow', (_message.Message,), dict(
  DESCRIPTOR = _UNAVAILABILITYWINDOW,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  ,
  __doc__ = """A time window during which a ground station is unavailable e.g. for
  local maintenance.
  
  
  Attributes:
      window_id:
          The ID of the unavailability window.
      start_time:
          Start time of the unavailabilty window.
      end_time:
          End time of the unavailability window.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.UnavailabilityWindow)
  ))
_sym_db.RegisterMessage(UnavailabilityWindow)

ListUnavailabilityWindowsRequest = _reflection.GeneratedProtocolMessageType('ListUnavailabilityWindowsRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTUNAVAILABILITYWINDOWSREQUEST,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  ,
  __doc__ = """A request for a list of unavailability windows for the specified ground
  station that fall within the given time range.
  
  
  Attributes:
      ground_station_id:
          ID of the ground station for which to retrieve unavailability
          windows.
      start_time:
          Start time.
      end_time:
          End time.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.ListUnavailabilityWindowsRequest)
  ))
_sym_db.RegisterMessage(ListUnavailabilityWindowsRequest)

ListUnavailabilityWindowsResponse = _reflection.GeneratedProtocolMessageType('ListUnavailabilityWindowsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTUNAVAILABILITYWINDOWSRESPONSE,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  ,
  __doc__ = """A response containing unavailability windows for the requested ground
  station.
  
  
  Attributes:
      window:
          A list of unavailability windows, sorted in ascending order of
          the start time.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.ListUnavailabilityWindowsResponse)
  ))
_sym_db.RegisterMessage(ListUnavailabilityWindowsResponse)

AddUnavailabilityWindowRequest = _reflection.GeneratedProtocolMessageType('AddUnavailabilityWindowRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDUNAVAILABILITYWINDOWREQUEST,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  ,
  __doc__ = """A request for adding a new unavailability window for the specified
  ground station.
  
  
  Attributes:
      ground_station_id:
          ID of the ground station to add a new unavailability window.
      start_time:
          Start time of the unavailabilty window.
      end_time:
          End time of the unavailability window.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.AddUnavailabilityWindowRequest)
  ))
_sym_db.RegisterMessage(AddUnavailabilityWindowRequest)

AddUnavailabilityWindowResponse = _reflection.GeneratedProtocolMessageType('AddUnavailabilityWindowResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDUNAVAILABILITYWINDOWRESPONSE,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  ,
  __doc__ = """A response from the ‘AddUnavailabilityWindow’ method.
  
  
  Attributes:
      window_id:
          ID of the new window.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.AddUnavailabilityWindowResponse)
  ))
_sym_db.RegisterMessage(AddUnavailabilityWindowResponse)

DeleteUnavailabilityWindowRequest = _reflection.GeneratedProtocolMessageType('DeleteUnavailabilityWindowRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEUNAVAILABILITYWINDOWREQUEST,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  ,
  __doc__ = """A request for deleting an existing unavailability window for the
  specified ground station.
  
  
  Attributes:
      window_id:
          ID of the unavailability window to delete.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.DeleteUnavailabilityWindowRequest)
  ))
_sym_db.RegisterMessage(DeleteUnavailabilityWindowRequest)

DeleteUnavailabilityWindowResponse = _reflection.GeneratedProtocolMessageType('DeleteUnavailabilityWindowResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEUNAVAILABILITYWINDOWRESPONSE,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  ,
  __doc__ = """A response to the request for deleting an existing unavailability
  window.
  
  Currently no payload in the response.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.DeleteUnavailabilityWindowResponse)
  ))
_sym_db.RegisterMessage(DeleteUnavailabilityWindowResponse)

GroundStationStreamRequest = _reflection.GeneratedProtocolMessageType('GroundStationStreamRequest', (_message.Message,), dict(
  DESCRIPTOR = _GROUNDSTATIONSTREAMREQUEST,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  ,
  __doc__ = """A payload to send on the ground station stream. The payload does not
  need to be filled on the first request to ``OpenGroundStationStream``.
  
  
  Attributes:
      ground_station_id:
          The ID of the ground station that is opening a stream. The ID
          of a ground station can be found on the StellarStation Console
          page for the ground station.
      stream_tag:
          A tag to identify this stream. This tag is not used
          semantically and is only for logging, monitoring, and
          debugging. This does not need to be set if there will only
          ever be one stream for a particular ``ground_station_id`` open
          at a time. If multiple streams will be open, this should be
          set to identify the stream. Some examples include ‘uplink’,
          ‘downlink’, ‘uhf’, ‘s-band’.
      stream_event:
          An event that occurred while processing the stream. Satellite
          operators will often use these events for debugging and
          monitoring.  -  ``command_sent`` must be returned right after
          completing transmission    of commands received in a
          ``SendSatelliteCommandsResponse``. -
          ``plan_monitoring_event.ground_station_configuration`` must be
          returned once at the beginning of the execution of a plan and
          contains information about the actual configuration of the
          ground    station at the time. -
          ``plan_monitoring_event.ground_station_state`` must be sent
          regularly    throughout the plan and contains real-time
          monitoring of the hardware    of the ground station. -
          ``plan_monitoring_event.ground_station_event`` must be sent
          once at    each of the transitions documented in
          ``PlanLifecycleEvent`` when    executing a plan.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.GroundStationStreamRequest)
  ))
_sym_db.RegisterMessage(GroundStationStreamRequest)

SatelliteTelemetry = _reflection.GeneratedProtocolMessageType('SatelliteTelemetry', (_message.Message,), dict(
  DESCRIPTOR = _SATELLITETELEMETRY,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  ,
  __doc__ = """Telemetry received from a satellite to send to a satellite operator.
  
  
  Attributes:
      plan_id:
          The ID of the plan the telemetry is being sent for.
      telemetry:
          The telemetry being sent.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.SatelliteTelemetry)
  ))
_sym_db.RegisterMessage(SatelliteTelemetry)

GroundStationStreamResponse = _reflection.GeneratedProtocolMessageType('GroundStationStreamResponse', (_message.Message,), dict(
  DESCRIPTOR = _GROUNDSTATIONSTREAMRESPONSE,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  ,
  __doc__ = """A payload sent on the stream to be processed by the ground station.
  Currently only commands to send to a satellite will be returned to the
  ground station.
  
  
  Attributes:
      plan_id:
          The ID of the plan this response corresponds to. Unfilled if
          this response does not correspond to a plan.
      response_id:
          A unique ID identifying this response. If filled, any
          ``StreamEvent`` generated when handling this
          GroundStationStreamResponse\ ``must have this value copied
          into``\ StreamEvent.request_id`. Currently, this includes  -
          Returning ``CommandSentFromGroundStation`` after completing
          transmission of the commands in a
          ``SendSatelliteCommandsResponse``.
      satellite_commands:
          Commands to send to the satellite.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.GroundStationStreamResponse)
  ))
_sym_db.RegisterMessage(GroundStationStreamResponse)

SatelliteCommands = _reflection.GeneratedProtocolMessageType('SatelliteCommands', (_message.Message,), dict(
  DESCRIPTOR = _SATELLITECOMMANDS,
  __module__ = 'stellarstation.api.v1.groundstation.groundstation_pb2'
  ,
  __doc__ = """Command to transmit to the satellite.
  
  
  Attributes:
      command:
          The command frames to send to the satellite. All commands must
          be transmitted in sequence immediately. After all commands
          have been transmitted, telemetry receive must be immediately
          enabled again.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.SatelliteCommands)
  ))
_sym_db.RegisterMessage(SatelliteCommands)


DESCRIPTOR._options = None

_GROUNDSTATIONSERVICE = _descriptor.ServiceDescriptor(
  name='GroundStationService',
  full_name='stellarstation.api.v1.groundstation.GroundStationService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2154,
  serialized_end=2979,
  methods=[
  _descriptor.MethodDescriptor(
    name='AddUnavailabilityWindow',
    full_name='stellarstation.api.v1.groundstation.GroundStationService.AddUnavailabilityWindow',
    index=0,
    containing_service=None,
    input_type=_ADDUNAVAILABILITYWINDOWREQUEST,
    output_type=_ADDUNAVAILABILITYWINDOWRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteUnavailabilityWindow',
    full_name='stellarstation.api.v1.groundstation.GroundStationService.DeleteUnavailabilityWindow',
    index=1,
    containing_service=None,
    input_type=_DELETEUNAVAILABILITYWINDOWREQUEST,
    output_type=_DELETEUNAVAILABILITYWINDOWRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListPlans',
    full_name='stellarstation.api.v1.groundstation.GroundStationService.ListPlans',
    index=2,
    containing_service=None,
    input_type=_LISTPLANSREQUEST,
    output_type=_LISTPLANSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListUnavailabilityWindows',
    full_name='stellarstation.api.v1.groundstation.GroundStationService.ListUnavailabilityWindows',
    index=3,
    containing_service=None,
    input_type=_LISTUNAVAILABILITYWINDOWSREQUEST,
    output_type=_LISTUNAVAILABILITYWINDOWSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='OpenGroundStationStream',
    full_name='stellarstation.api.v1.groundstation.GroundStationService.OpenGroundStationStream',
    index=4,
    containing_service=None,
    input_type=_GROUNDSTATIONSTREAMREQUEST,
    output_type=_GROUNDSTATIONSTREAMRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_GROUNDSTATIONSERVICE)

DESCRIPTOR.services_by_name['GroundStationService'] = _GROUNDSTATIONSERVICE

# @@protoc_insertion_point(module_scope)
