# -*- coding: utf-8 -*-
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stellarstation/api/v1/antenna/antenna.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='stellarstation/api/v1/antenna/antenna.proto',
  package='stellarstation.api.v1.antenna',
  syntax='proto3',
  serialized_options=_b('\n!com.stellarstation.api.v1.antennaB\014AntennaProtoP\001Z:github.com/infostellarinc/go-stellarstation/api/v1/antenna'),
  serialized_pb=_b('\n+stellarstation/api/v1/antenna/antenna.proto\x12\x1dstellarstation.api.v1.antenna\"o\n\x14\x41ntennaConfiguration\x12\x10\n\x08latitude\x18\x01 \x01(\x01\x12\x11\n\tlongitude\x18\x02 \x01(\x01\x12\x17\n\x0f\x61ltitude_meters\x18\x03 \x01(\x01\x12\x19\n\x11\x62\x65\x61mwidth_degrees\x18\x04 \x01(\x01*G\n\x13\x41ntennaPolarization\x12\x0e\n\nHORIZONTAL\x10\x00\x12\x0c\n\x08VERTICAL\x10\x01\x12\x08\n\x04LHCP\x10\x02\x12\x08\n\x04RHCP\x10\x03\x42o\n!com.stellarstation.api.v1.antennaB\x0c\x41ntennaProtoP\x01Z:github.com/infostellarinc/go-stellarstation/api/v1/antennab\x06proto3')
)

_ANTENNAPOLARIZATION = _descriptor.EnumDescriptor(
  name='AntennaPolarization',
  full_name='stellarstation.api.v1.antenna.AntennaPolarization',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HORIZONTAL', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VERTICAL', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LHCP', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RHCP', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=191,
  serialized_end=262,
)
_sym_db.RegisterEnumDescriptor(_ANTENNAPOLARIZATION)

AntennaPolarization = enum_type_wrapper.EnumTypeWrapper(_ANTENNAPOLARIZATION)
HORIZONTAL = 0
VERTICAL = 1
LHCP = 2
RHCP = 3



_ANTENNACONFIGURATION = _descriptor.Descriptor(
  name='AntennaConfiguration',
  full_name='stellarstation.api.v1.antenna.AntennaConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='latitude', full_name='stellarstation.api.v1.antenna.AntennaConfiguration.latitude', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longitude', full_name='stellarstation.api.v1.antenna.AntennaConfiguration.longitude', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='altitude_meters', full_name='stellarstation.api.v1.antenna.AntennaConfiguration.altitude_meters', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='beamwidth_degrees', full_name='stellarstation.api.v1.antenna.AntennaConfiguration.beamwidth_degrees', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=78,
  serialized_end=189,
)

DESCRIPTOR.message_types_by_name['AntennaConfiguration'] = _ANTENNACONFIGURATION
DESCRIPTOR.enum_types_by_name['AntennaPolarization'] = _ANTENNAPOLARIZATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AntennaConfiguration = _reflection.GeneratedProtocolMessageType('AntennaConfiguration', (_message.Message,), dict(
  DESCRIPTOR = _ANTENNACONFIGURATION,
  __module__ = 'stellarstation.api.v1.antenna.antenna_pb2'
  ,
  __doc__ = """The static configuration of an antenna. These are the physical
  parameters of the antenna.
  
  
  Attributes:
      latitude:
          The latitude of the antenna, in degrees.
      longitude:
          The longitude of the antenna, in degrees.
      altitude_meters:
          The altitude of the antenna above mean sea level, in meters.
      beamwidth_degrees:
          The beamwidth, in degrees.
          https://en.wikipedia.org/wiki/Beamwidth
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.antenna.AntennaConfiguration)
  ))
_sym_db.RegisterMessage(AntennaConfiguration)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
