# -*- coding: utf-8 -*-
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stellarstation/api/v1/radio/radio.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='stellarstation/api/v1/radio/radio.proto',
  package='stellarstation.api.v1.radio',
  syntax='proto3',
  serialized_options=_b('\n\037com.stellarstation.api.v1.radioB\nRadioProtoP\001Z8github.com/infostellarinc/go-stellarstation/api/v1/radio'),
  serialized_pb=_b('\n\'stellarstation/api/v1/radio/radio.proto\x12\x1bstellarstation.api.v1.radio\"\xcb\x01\n\x18RadioDeviceConfiguration\x12\x1b\n\x13\x63\x65nter_frequency_hz\x18\x01 \x01(\x04\x12;\n\nmodulation\x18\x02 \x01(\x0e\x32\'.stellarstation.api.v1.radio.Modulation\x12\x0f\n\x07\x62itrate\x18\x03 \x01(\x04\x12\x44\n\x08protocol\x18\x04 \x01(\x0b\x32\x32.stellarstation.api.v1.radio.CommunicationProtocol\"\x90\x02\n\x15\x43ommunicationProtocol\x12\x31\n\x04\x61x25\x18\x01 \x01(\x0b\x32!.stellarstation.api.v1.radio.AX25H\x00\x12@\n\x05\x63\x63sds\x18\x02 \x01(\x0b\x32/.stellarstation.api.v1.radio.CCSDSTransferFrameH\x00\x12;\n\tbitstream\x18\x03 \x01(\x0b\x32&.stellarstation.api.v1.radio.BitstreamH\x00\x12:\n\tasm_golay\x18\x04 \x01(\x0b\x32%.stellarstation.api.v1.radio.ASMGolayH\x00\x42\t\n\x07\x46raming\"\xc4\x03\n\x1e\x43\x43SDSConvolutionalCodingParams\x12m\n\x14polynomial_inversion\x18\x01 \x01(\x0e\x32O.stellarstation.api.v1.radio.CCSDSConvolutionalCodingParams.PolynomialInversion\x12Z\n\npuncturing\x18\x02 \x01(\x0e\x32\x46.stellarstation.api.v1.radio.CCSDSConvolutionalCodingParams.Puncturing\"S\n\x13PolynomialInversion\x12\t\n\x05G1_G2\x10\x00\x12\x12\n\x0eG1_G2_INVERTED\x10\x01\x12\x12\n\x0eG2_INVERTED_G1\x10\x02\x12\t\n\x05G2_G1\x10\x03\"\x81\x01\n\nPuncturing\x12\x07\n\x03OFF\x10\x00\x12\x10\n\x0cPUNCTURE_2_3\x10\x01\x12\x10\n\x0cPUNCTURE_3_4\x10\x02\x12\x10\n\x0cPUNCTURE_4_5\x10\x03\x12\x10\n\x0cPUNCTURE_5_6\x10\x04\x12\x10\n\x0cPUNCTURE_6_7\x10\x05\x12\x10\n\x0cPUNCTURE_7_8\x10\x06\"\x17\n\x15\x43\x43SDSScramblingParams\"\xab\x01\n\x16\x43\x43SDSReedSolomonParams\x12^\n\x11\x62lock_length_type\x18\x01 \x01(\x0e\x32\x43.stellarstation.api.v1.radio.CCSDSReedSolomonParams.BlockLengthType\"1\n\x0f\x42lockLengthType\x12\x0e\n\nRS_223_255\x10\x00\x12\x0e\n\nRS_239_255\x10\x01\"\xc5\x03\n\x12\x43\x43SDSTransferFrame\x12R\n\x16synchronization_params\x18\x01 \x01(\x0b\x32\x32.stellarstation.api.v1.radio.SynchronizationParams\x12`\n\x1b\x63onvolutional_coding_params\x18\x02 \x01(\x0b\x32;.stellarstation.api.v1.radio.CCSDSConvolutionalCodingParams\x12M\n\x11scrambling_params\x18\x03 \x01(\x0b\x32\x32.stellarstation.api.v1.radio.CCSDSScramblingParams\x12P\n\x13reed_solomon_params\x18\x04 \x01(\x0b\x32\x33.stellarstation.api.v1.radio.CCSDSReedSolomonParams\x12\x1a\n\x12\x66rame_length_bytes\x18\x05 \x01(\r\x12<\n\x0bline_coding\x18\x06 \x01(\x0e\x32\'.stellarstation.api.v1.radio.LineCoding\"\xb4\x01\n\x08\x41SMGolay\x12R\n\x16synchronization_params\x18\x01 \x01(\x0b\x32\x32.stellarstation.api.v1.radio.SynchronizationParams\x12\x1d\n\x15\x65nable_ccsds_scramble\x18\x02 \x01(\x08\x12\x1b\n\x13\x65nable_reed_solomon\x18\x03 \x01(\x08\x12\x18\n\x10\x65nable_crc_check\x18\x04 \x01(\x08\"\xb9\x01\n\tBitstream\x12R\n\x16synchronization_params\x18\x01 \x01(\x0b\x32\x32.stellarstation.api.v1.radio.SynchronizationParams\x12\x1a\n\x12\x66rame_length_bytes\x18\x02 \x01(\r\x12<\n\x0bline_coding\x18\x03 \x01(\x0e\x32\'.stellarstation.api.v1.radio.LineCoding\"J\n\x15SynchronizationParams\x12\x1c\n\x14synchronization_word\x18\x01 \x01(\x0c\x12\x13\n\x0blength_bits\x18\x02 \x01(\r\"{\n\x04\x41X25\x12\r\n\x05g3ruh\x18\x01 \x01(\x08\x12\x1c\n\x14\x64\x65stination_callsign\x18\x02 \x01(\t\x12\x18\n\x10\x64\x65stination_ssid\x18\x03 \x01(\r\x12\x17\n\x0fsource_callsign\x18\x04 \x01(\t\x12\x13\n\x0bsource_ssid\x18\x05 \x01(\r\"P\n\x19\x43onvolutionalCodingParams\x12\t\n\x01k\x18\x01 \x01(\r\x12\x14\n\x0cinverse_rate\x18\x02 \x01(\r\x12\x12\n\npolynomial\x18\x03 \x03(\x0c\"\xac\x01\n\x10ScramblingParams\x12@\n\x04type\x18\x01 \x01(\x0e\x32\x32.stellarstation.api.v1.radio.ScramblingParams.Type\x12\x10\n\x08num_bits\x18\x02 \x01(\r\x12\x0c\n\x04mask\x18\x03 \x01(\x0c\x12\x0c\n\x04seed\x18\x04 \x01(\x0c\"(\n\x04Type\x12\x0c\n\x08\x41\x44\x44ITIVE\x10\x00\x12\x12\n\x0eMULTIPLICATIVE\x10\x01*\x87\x02\n\nModulation\x12\x0c\n\x08\x44ISABLED\x10\x00\x12\x07\n\x03\x46SK\x10\x01\x12\x08\n\x04\x41\x46SK\x10\x02\x12\x08\n\x04\x42PSK\x10\x03\x12\x08\n\x04MFSK\x10\x04\x12\x08\n\x04QPSK\x10\x05\x12\x08\n\x04PSK8\x10\x06\x12\t\n\x05PSK16\x10\x07\x12\t\n\x05PSK32\x10\x08\x12\t\n\x05PSK64\x10\t\x12\n\n\x06PSK128\x10\n\x12\n\n\x06PSK256\x10\x0b\x12\t\n\x05OQPSK\x10\x0c\x12\x08\n\x04QAM8\x10\r\x12\t\n\x05QAM16\x10\x0e\x12\t\n\x05QAM32\x10\x0f\x12\t\n\x05QAM64\x10\x10\x12\n\n\x06QAM128\x10\x11\x12\n\n\x06QAM256\x10\x12\x12\x07\n\x03MSK\x10\x13\x12\x08\n\x04GMSK\x10\x14\x12\x06\n\x02\x41M\x10\x15\x12\x06\n\x02\x46M\x10\x16\x12\x06\n\x02PM\x10\x17*S\n\nLineCoding\x12\t\n\x05NRZ_L\x10\x00\x12\t\n\x05NRZ_M\x10\x01\x12\t\n\x05NRZ_S\x10\x02\x12\x06\n\x02RZ\x10\x03\x12\x08\n\x04\x42P_L\x10\x04\x12\x08\n\x04\x42P_M\x10\x05\x12\x08\n\x04\x42P_S\x10\x06\x42i\n\x1f\x63om.stellarstation.api.v1.radioB\nRadioProtoP\x01Z8github.com/infostellarinc/go-stellarstation/api/v1/radiob\x06proto3')
)

_MODULATION = _descriptor.EnumDescriptor(
  name='Modulation',
  full_name='stellarstation.api.v1.radio.Modulation',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DISABLED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FSK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AFSK', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BPSK', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MFSK', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QPSK', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PSK8', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PSK16', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PSK32', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PSK64', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PSK128', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PSK256', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OQPSK', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QAM8', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QAM16', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QAM32', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QAM64', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QAM128', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QAM256', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MSK', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GMSK', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AM', index=21, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FM', index=22, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PM', index=23, number=23,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2493,
  serialized_end=2756,
)
_sym_db.RegisterEnumDescriptor(_MODULATION)

Modulation = enum_type_wrapper.EnumTypeWrapper(_MODULATION)
_LINECODING = _descriptor.EnumDescriptor(
  name='LineCoding',
  full_name='stellarstation.api.v1.radio.LineCoding',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NRZ_L', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NRZ_M', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NRZ_S', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RZ', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BP_L', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BP_M', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BP_S', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2758,
  serialized_end=2841,
)
_sym_db.RegisterEnumDescriptor(_LINECODING)

LineCoding = enum_type_wrapper.EnumTypeWrapper(_LINECODING)
DISABLED = 0
FSK = 1
AFSK = 2
BPSK = 3
MFSK = 4
QPSK = 5
PSK8 = 6
PSK16 = 7
PSK32 = 8
PSK64 = 9
PSK128 = 10
PSK256 = 11
OQPSK = 12
QAM8 = 13
QAM16 = 14
QAM32 = 15
QAM64 = 16
QAM128 = 17
QAM256 = 18
MSK = 19
GMSK = 20
AM = 21
FM = 22
PM = 23
NRZ_L = 0
NRZ_M = 1
NRZ_S = 2
RZ = 3
BP_L = 4
BP_M = 5
BP_S = 6


_CCSDSCONVOLUTIONALCODINGPARAMS_POLYNOMIALINVERSION = _descriptor.EnumDescriptor(
  name='PolynomialInversion',
  full_name='stellarstation.api.v1.radio.CCSDSConvolutionalCodingParams.PolynomialInversion',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='G1_G2', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='G1_G2_INVERTED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='G2_INVERTED_G1', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='G2_G1', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=791,
  serialized_end=874,
)
_sym_db.RegisterEnumDescriptor(_CCSDSCONVOLUTIONALCODINGPARAMS_POLYNOMIALINVERSION)

_CCSDSCONVOLUTIONALCODINGPARAMS_PUNCTURING = _descriptor.EnumDescriptor(
  name='Puncturing',
  full_name='stellarstation.api.v1.radio.CCSDSConvolutionalCodingParams.Puncturing',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OFF', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PUNCTURE_2_3', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PUNCTURE_3_4', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PUNCTURE_4_5', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PUNCTURE_5_6', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PUNCTURE_6_7', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PUNCTURE_7_8', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=877,
  serialized_end=1006,
)
_sym_db.RegisterEnumDescriptor(_CCSDSCONVOLUTIONALCODINGPARAMS_PUNCTURING)

_CCSDSREEDSOLOMONPARAMS_BLOCKLENGTHTYPE = _descriptor.EnumDescriptor(
  name='BlockLengthType',
  full_name='stellarstation.api.v1.radio.CCSDSReedSolomonParams.BlockLengthType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RS_223_255', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RS_239_255', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1156,
  serialized_end=1205,
)
_sym_db.RegisterEnumDescriptor(_CCSDSREEDSOLOMONPARAMS_BLOCKLENGTHTYPE)

_SCRAMBLINGPARAMS_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='stellarstation.api.v1.radio.ScramblingParams.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ADDITIVE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MULTIPLICATIVE', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2450,
  serialized_end=2490,
)
_sym_db.RegisterEnumDescriptor(_SCRAMBLINGPARAMS_TYPE)


_RADIODEVICECONFIGURATION = _descriptor.Descriptor(
  name='RadioDeviceConfiguration',
  full_name='stellarstation.api.v1.radio.RadioDeviceConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='center_frequency_hz', full_name='stellarstation.api.v1.radio.RadioDeviceConfiguration.center_frequency_hz', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='modulation', full_name='stellarstation.api.v1.radio.RadioDeviceConfiguration.modulation', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bitrate', full_name='stellarstation.api.v1.radio.RadioDeviceConfiguration.bitrate', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='stellarstation.api.v1.radio.RadioDeviceConfiguration.protocol', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=73,
  serialized_end=276,
)


_COMMUNICATIONPROTOCOL = _descriptor.Descriptor(
  name='CommunicationProtocol',
  full_name='stellarstation.api.v1.radio.CommunicationProtocol',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ax25', full_name='stellarstation.api.v1.radio.CommunicationProtocol.ax25', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ccsds', full_name='stellarstation.api.v1.radio.CommunicationProtocol.ccsds', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bitstream', full_name='stellarstation.api.v1.radio.CommunicationProtocol.bitstream', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='asm_golay', full_name='stellarstation.api.v1.radio.CommunicationProtocol.asm_golay', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Framing', full_name='stellarstation.api.v1.radio.CommunicationProtocol.Framing',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=279,
  serialized_end=551,
)


_CCSDSCONVOLUTIONALCODINGPARAMS = _descriptor.Descriptor(
  name='CCSDSConvolutionalCodingParams',
  full_name='stellarstation.api.v1.radio.CCSDSConvolutionalCodingParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='polynomial_inversion', full_name='stellarstation.api.v1.radio.CCSDSConvolutionalCodingParams.polynomial_inversion', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='puncturing', full_name='stellarstation.api.v1.radio.CCSDSConvolutionalCodingParams.puncturing', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CCSDSCONVOLUTIONALCODINGPARAMS_POLYNOMIALINVERSION,
    _CCSDSCONVOLUTIONALCODINGPARAMS_PUNCTURING,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=554,
  serialized_end=1006,
)


_CCSDSSCRAMBLINGPARAMS = _descriptor.Descriptor(
  name='CCSDSScramblingParams',
  full_name='stellarstation.api.v1.radio.CCSDSScramblingParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1008,
  serialized_end=1031,
)


_CCSDSREEDSOLOMONPARAMS = _descriptor.Descriptor(
  name='CCSDSReedSolomonParams',
  full_name='stellarstation.api.v1.radio.CCSDSReedSolomonParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_length_type', full_name='stellarstation.api.v1.radio.CCSDSReedSolomonParams.block_length_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CCSDSREEDSOLOMONPARAMS_BLOCKLENGTHTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1034,
  serialized_end=1205,
)


_CCSDSTRANSFERFRAME = _descriptor.Descriptor(
  name='CCSDSTransferFrame',
  full_name='stellarstation.api.v1.radio.CCSDSTransferFrame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='synchronization_params', full_name='stellarstation.api.v1.radio.CCSDSTransferFrame.synchronization_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='convolutional_coding_params', full_name='stellarstation.api.v1.radio.CCSDSTransferFrame.convolutional_coding_params', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scrambling_params', full_name='stellarstation.api.v1.radio.CCSDSTransferFrame.scrambling_params', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reed_solomon_params', full_name='stellarstation.api.v1.radio.CCSDSTransferFrame.reed_solomon_params', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frame_length_bytes', full_name='stellarstation.api.v1.radio.CCSDSTransferFrame.frame_length_bytes', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_coding', full_name='stellarstation.api.v1.radio.CCSDSTransferFrame.line_coding', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1208,
  serialized_end=1661,
)


_ASMGOLAY = _descriptor.Descriptor(
  name='ASMGolay',
  full_name='stellarstation.api.v1.radio.ASMGolay',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='synchronization_params', full_name='stellarstation.api.v1.radio.ASMGolay.synchronization_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enable_ccsds_scramble', full_name='stellarstation.api.v1.radio.ASMGolay.enable_ccsds_scramble', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enable_reed_solomon', full_name='stellarstation.api.v1.radio.ASMGolay.enable_reed_solomon', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enable_crc_check', full_name='stellarstation.api.v1.radio.ASMGolay.enable_crc_check', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1664,
  serialized_end=1844,
)


_BITSTREAM = _descriptor.Descriptor(
  name='Bitstream',
  full_name='stellarstation.api.v1.radio.Bitstream',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='synchronization_params', full_name='stellarstation.api.v1.radio.Bitstream.synchronization_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frame_length_bytes', full_name='stellarstation.api.v1.radio.Bitstream.frame_length_bytes', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_coding', full_name='stellarstation.api.v1.radio.Bitstream.line_coding', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1847,
  serialized_end=2032,
)


_SYNCHRONIZATIONPARAMS = _descriptor.Descriptor(
  name='SynchronizationParams',
  full_name='stellarstation.api.v1.radio.SynchronizationParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='synchronization_word', full_name='stellarstation.api.v1.radio.SynchronizationParams.synchronization_word', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='length_bits', full_name='stellarstation.api.v1.radio.SynchronizationParams.length_bits', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2034,
  serialized_end=2108,
)


_AX25 = _descriptor.Descriptor(
  name='AX25',
  full_name='stellarstation.api.v1.radio.AX25',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='g3ruh', full_name='stellarstation.api.v1.radio.AX25.g3ruh', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destination_callsign', full_name='stellarstation.api.v1.radio.AX25.destination_callsign', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destination_ssid', full_name='stellarstation.api.v1.radio.AX25.destination_ssid', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source_callsign', full_name='stellarstation.api.v1.radio.AX25.source_callsign', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source_ssid', full_name='stellarstation.api.v1.radio.AX25.source_ssid', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2110,
  serialized_end=2233,
)


_CONVOLUTIONALCODINGPARAMS = _descriptor.Descriptor(
  name='ConvolutionalCodingParams',
  full_name='stellarstation.api.v1.radio.ConvolutionalCodingParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='k', full_name='stellarstation.api.v1.radio.ConvolutionalCodingParams.k', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inverse_rate', full_name='stellarstation.api.v1.radio.ConvolutionalCodingParams.inverse_rate', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='polynomial', full_name='stellarstation.api.v1.radio.ConvolutionalCodingParams.polynomial', index=2,
      number=3, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2235,
  serialized_end=2315,
)


_SCRAMBLINGPARAMS = _descriptor.Descriptor(
  name='ScramblingParams',
  full_name='stellarstation.api.v1.radio.ScramblingParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='stellarstation.api.v1.radio.ScramblingParams.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_bits', full_name='stellarstation.api.v1.radio.ScramblingParams.num_bits', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mask', full_name='stellarstation.api.v1.radio.ScramblingParams.mask', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seed', full_name='stellarstation.api.v1.radio.ScramblingParams.seed', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SCRAMBLINGPARAMS_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2318,
  serialized_end=2490,
)

_RADIODEVICECONFIGURATION.fields_by_name['modulation'].enum_type = _MODULATION
_RADIODEVICECONFIGURATION.fields_by_name['protocol'].message_type = _COMMUNICATIONPROTOCOL
_COMMUNICATIONPROTOCOL.fields_by_name['ax25'].message_type = _AX25
_COMMUNICATIONPROTOCOL.fields_by_name['ccsds'].message_type = _CCSDSTRANSFERFRAME
_COMMUNICATIONPROTOCOL.fields_by_name['bitstream'].message_type = _BITSTREAM
_COMMUNICATIONPROTOCOL.fields_by_name['asm_golay'].message_type = _ASMGOLAY
_COMMUNICATIONPROTOCOL.oneofs_by_name['Framing'].fields.append(
  _COMMUNICATIONPROTOCOL.fields_by_name['ax25'])
_COMMUNICATIONPROTOCOL.fields_by_name['ax25'].containing_oneof = _COMMUNICATIONPROTOCOL.oneofs_by_name['Framing']
_COMMUNICATIONPROTOCOL.oneofs_by_name['Framing'].fields.append(
  _COMMUNICATIONPROTOCOL.fields_by_name['ccsds'])
_COMMUNICATIONPROTOCOL.fields_by_name['ccsds'].containing_oneof = _COMMUNICATIONPROTOCOL.oneofs_by_name['Framing']
_COMMUNICATIONPROTOCOL.oneofs_by_name['Framing'].fields.append(
  _COMMUNICATIONPROTOCOL.fields_by_name['bitstream'])
_COMMUNICATIONPROTOCOL.fields_by_name['bitstream'].containing_oneof = _COMMUNICATIONPROTOCOL.oneofs_by_name['Framing']
_COMMUNICATIONPROTOCOL.oneofs_by_name['Framing'].fields.append(
  _COMMUNICATIONPROTOCOL.fields_by_name['asm_golay'])
_COMMUNICATIONPROTOCOL.fields_by_name['asm_golay'].containing_oneof = _COMMUNICATIONPROTOCOL.oneofs_by_name['Framing']
_CCSDSCONVOLUTIONALCODINGPARAMS.fields_by_name['polynomial_inversion'].enum_type = _CCSDSCONVOLUTIONALCODINGPARAMS_POLYNOMIALINVERSION
_CCSDSCONVOLUTIONALCODINGPARAMS.fields_by_name['puncturing'].enum_type = _CCSDSCONVOLUTIONALCODINGPARAMS_PUNCTURING
_CCSDSCONVOLUTIONALCODINGPARAMS_POLYNOMIALINVERSION.containing_type = _CCSDSCONVOLUTIONALCODINGPARAMS
_CCSDSCONVOLUTIONALCODINGPARAMS_PUNCTURING.containing_type = _CCSDSCONVOLUTIONALCODINGPARAMS
_CCSDSREEDSOLOMONPARAMS.fields_by_name['block_length_type'].enum_type = _CCSDSREEDSOLOMONPARAMS_BLOCKLENGTHTYPE
_CCSDSREEDSOLOMONPARAMS_BLOCKLENGTHTYPE.containing_type = _CCSDSREEDSOLOMONPARAMS
_CCSDSTRANSFERFRAME.fields_by_name['synchronization_params'].message_type = _SYNCHRONIZATIONPARAMS
_CCSDSTRANSFERFRAME.fields_by_name['convolutional_coding_params'].message_type = _CCSDSCONVOLUTIONALCODINGPARAMS
_CCSDSTRANSFERFRAME.fields_by_name['scrambling_params'].message_type = _CCSDSSCRAMBLINGPARAMS
_CCSDSTRANSFERFRAME.fields_by_name['reed_solomon_params'].message_type = _CCSDSREEDSOLOMONPARAMS
_CCSDSTRANSFERFRAME.fields_by_name['line_coding'].enum_type = _LINECODING
_ASMGOLAY.fields_by_name['synchronization_params'].message_type = _SYNCHRONIZATIONPARAMS
_BITSTREAM.fields_by_name['synchronization_params'].message_type = _SYNCHRONIZATIONPARAMS
_BITSTREAM.fields_by_name['line_coding'].enum_type = _LINECODING
_SCRAMBLINGPARAMS.fields_by_name['type'].enum_type = _SCRAMBLINGPARAMS_TYPE
_SCRAMBLINGPARAMS_TYPE.containing_type = _SCRAMBLINGPARAMS
DESCRIPTOR.message_types_by_name['RadioDeviceConfiguration'] = _RADIODEVICECONFIGURATION
DESCRIPTOR.message_types_by_name['CommunicationProtocol'] = _COMMUNICATIONPROTOCOL
DESCRIPTOR.message_types_by_name['CCSDSConvolutionalCodingParams'] = _CCSDSCONVOLUTIONALCODINGPARAMS
DESCRIPTOR.message_types_by_name['CCSDSScramblingParams'] = _CCSDSSCRAMBLINGPARAMS
DESCRIPTOR.message_types_by_name['CCSDSReedSolomonParams'] = _CCSDSREEDSOLOMONPARAMS
DESCRIPTOR.message_types_by_name['CCSDSTransferFrame'] = _CCSDSTRANSFERFRAME
DESCRIPTOR.message_types_by_name['ASMGolay'] = _ASMGOLAY
DESCRIPTOR.message_types_by_name['Bitstream'] = _BITSTREAM
DESCRIPTOR.message_types_by_name['SynchronizationParams'] = _SYNCHRONIZATIONPARAMS
DESCRIPTOR.message_types_by_name['AX25'] = _AX25
DESCRIPTOR.message_types_by_name['ConvolutionalCodingParams'] = _CONVOLUTIONALCODINGPARAMS
DESCRIPTOR.message_types_by_name['ScramblingParams'] = _SCRAMBLINGPARAMS
DESCRIPTOR.enum_types_by_name['Modulation'] = _MODULATION
DESCRIPTOR.enum_types_by_name['LineCoding'] = _LINECODING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RadioDeviceConfiguration = _reflection.GeneratedProtocolMessageType('RadioDeviceConfiguration', (_message.Message,), dict(
  DESCRIPTOR = _RADIODEVICECONFIGURATION,
  __module__ = 'stellarstation.api.v1.radio.radio_pb2'
  ,
  __doc__ = """A radio device for RF communication. Usually, a satellite will have one
  or more radio devices for communicating with the ground and a ground
  station will have one or more radio devices for communicating with the
  satellite. Such devices may not actually correspond to actual hardware
  devices, i.e., in the case of Software Defined Radio (SDR).
  
  
  Attributes:
      center_frequency_hz:
          The center frequency of the device, in Hz.
      modulation:
          The type of modulation used by this radio device.
      bitrate:
          The bitrate used during modulation.
      protocol:
          The protocol used by this device when doing RF communication.
          If unset, the device is only demodulating / modulating without
          applying any higher-level communication protocol.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.radio.RadioDeviceConfiguration)
  ))
_sym_db.RegisterMessage(RadioDeviceConfiguration)

CommunicationProtocol = _reflection.GeneratedProtocolMessageType('CommunicationProtocol', (_message.Message,), dict(
  DESCRIPTOR = _COMMUNICATIONPROTOCOL,
  __module__ = 'stellarstation.api.v1.radio.radio_pb2'
  ,
  __doc__ = """A communication protocol used with a radio device. These must contain
  all the parameters needed to configure the device for use either in
  transmission or reception.
  
  
  Attributes:
      ax25:
          AX.25 protocol settings.
      ccsds:
          CCSDS transfer frame settings.
      bitstream:
          Bitstream framing settings.
      asm_golay:
          AX 100 ASM + Golay mode.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.radio.CommunicationProtocol)
  ))
_sym_db.RegisterMessage(CommunicationProtocol)

CCSDSConvolutionalCodingParams = _reflection.GeneratedProtocolMessageType('CCSDSConvolutionalCodingParams', (_message.Message,), dict(
  DESCRIPTOR = _CCSDSCONVOLUTIONALCODINGPARAMS,
  __module__ = 'stellarstation.api.v1.radio.radio_pb2'
  ,
  __doc__ = """CCSDS-specific convolutional coding parameters. Code rate (r): 1/2
  Constraint length (K): 7 Connection vectors: G1 = 1111001 G2 = 1011011
  
  
  Attributes:
      puncturing:
          Optional puncturing for convolutional code.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.radio.CCSDSConvolutionalCodingParams)
  ))
_sym_db.RegisterMessage(CCSDSConvolutionalCodingParams)

CCSDSScramblingParams = _reflection.GeneratedProtocolMessageType('CCSDSScramblingParams', (_message.Message,), dict(
  DESCRIPTOR = _CCSDSSCRAMBLINGPARAMS,
  __module__ = 'stellarstation.api.v1.radio.radio_pb2'
  ,
  __doc__ = """CCSDS-specific scrambling parameters. Additive scrambler with
  pseudo-random sequence generated by the polynomial: h(x) = x^8 + x^7 +
  x^5 + x^3 + 1
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.radio.CCSDSScramblingParams)
  ))
_sym_db.RegisterMessage(CCSDSScramblingParams)

CCSDSReedSolomonParams = _reflection.GeneratedProtocolMessageType('CCSDSReedSolomonParams', (_message.Message,), dict(
  DESCRIPTOR = _CCSDSREEDSOLOMONPARAMS,
  __module__ = 'stellarstation.api.v1.radio.radio_pb2'
  ,
  __doc__ = """CCSDS-specific Reed-Solomon parameters.
  
  
  Attributes:
      block_length_type:
          Block length type for RS code.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.radio.CCSDSReedSolomonParams)
  ))
_sym_db.RegisterMessage(CCSDSReedSolomonParams)

CCSDSTransferFrame = _reflection.GeneratedProtocolMessageType('CCSDSTransferFrame', (_message.Message,), dict(
  DESCRIPTOR = _CCSDSTRANSFERFRAME,
  __module__ = 'stellarstation.api.v1.radio.radio_pb2'
  ,
  __doc__ = """https://public.ccsds.org/Pubs/131x0b3e1.pdf
  
  CCSDS transfer frames allow for a few common variations satellites use
  such as setting a custom synchronization word, inverting the
  convolutional coding polynomials, etc. The sequence of error-correcting
  codes will be applied as they are defined in the CCSDS standard.
  
  
  Attributes:
      synchronization_params:
          Synchronization word parameters. If unset, synchronization
          will be enabled using the default CCSDS transfer frame
          standard synchronization word as in 9.3.5 (Page 9-3) in the
          specification.
      convolutional_coding_params:
          Convolutional coding parameters. If unset, convolutional
          coding is disabled.
      scrambling_params:
          Scrambling parameters. If unset, scrambling is disabled.
      reed_solomon_params:
          Reed-Solomon parameters. If unset, Reed-Solomon is disabled.
      frame_length_bytes:
          Frame length, in bytes.
      line_coding:
          Line coding used.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.radio.CCSDSTransferFrame)
  ))
_sym_db.RegisterMessage(CCSDSTransferFrame)

ASMGolay = _reflection.GeneratedProtocolMessageType('ASMGolay', (_message.Message,), dict(
  DESCRIPTOR = _ASMGOLAY,
  __module__ = 'stellarstation.api.v1.radio.radio_pb2'
  ,
  __doc__ = """ASM+Golay mode for GOM Space AX100 radio.
  https://gomspace.com/UserFiles/Subsystems/datasheet/gs-ds-nanocom-ax100-33.pdf
  
  
  Attributes:
      synchronization_params:
          Synchronization word parameters. If unset, the default
          synchronization word defined by the AX100 will be used.
      enable_ccsds_scramble:
          Whether to enable CCSDS scrambling.
      enable_reed_solomon:
          Whether to enable Reed Solomon error correction.
      enable_crc_check:
          Whether to enable CRC checking.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.radio.ASMGolay)
  ))
_sym_db.RegisterMessage(ASMGolay)

Bitstream = _reflection.GeneratedProtocolMessageType('Bitstream', (_message.Message,), dict(
  DESCRIPTOR = _BITSTREAM,
  __module__ = 'stellarstation.api.v1.radio.radio_pb2'
  ,
  __doc__ = """Framing for satellites that don’t conform to a particular standard.
  Usually, only a synchronization word and expected frame length can be
  set.
  
  
  Attributes:
      synchronization_params:
          Synchronization word parameters. If unset, synchronization is
          disabled.
      frame_length_bytes:
          Frame length, in bytes.
      line_coding:
          Line coding used.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.radio.Bitstream)
  ))
_sym_db.RegisterMessage(Bitstream)

SynchronizationParams = _reflection.GeneratedProtocolMessageType('SynchronizationParams', (_message.Message,), dict(
  DESCRIPTOR = _SYNCHRONIZATIONPARAMS,
  __module__ = 'stellarstation.api.v1.radio.radio_pb2'
  ,
  __doc__ = """Parameters for frame synchronization.
  
  
  Attributes:
      synchronization_word:
          The actual bytes of the synchronization word. Least
          significant bit aligned E.g. 15-bit sync word of 0x7fff should
          be represented as 0111 1111 1111 1111 or [0x7f, 0xff]
      length_bits:
          The length in bits of the synchronization word.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.radio.SynchronizationParams)
  ))
_sym_db.RegisterMessage(SynchronizationParams)

AX25 = _reflection.GeneratedProtocolMessageType('AX25', (_message.Message,), dict(
  DESCRIPTOR = _AX25,
  __module__ = 'stellarstation.api.v1.radio.radio_pb2'
  ,
  __doc__ = """PACKET communication based on AX.25.
  https://www.sigidwiki.com/wiki/PACKET.
  
  
  Attributes:
      g3ruh:
          Whether or not G3RUH scrambling is used.
      destination_callsign:
          Destination callsign.
      destination_ssid:
          Destination SSID.
      source_callsign:
          Source callsign.
      source_ssid:
          Source SSID.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.radio.AX25)
  ))
_sym_db.RegisterMessage(AX25)

ConvolutionalCodingParams = _reflection.GeneratedProtocolMessageType('ConvolutionalCodingParams', (_message.Message,), dict(
  DESCRIPTOR = _CONVOLUTIONALCODINGPARAMS,
  __module__ = 'stellarstation.api.v1.radio.radio_pb2'
  ,
  __doc__ = """Parameters for convolutional coding applied to a bitstream.
  https://en.wikipedia.org/wiki/Convolutional_code
  
  
  Attributes:
      k:
          The constraint length, ``k``, of the code.
      inverse_rate:
          The inverse of the rate of coding, e.g., if rate is ``1 / r``,
          ``inverse_rate`` is ``r``.
      polynomial:
          The polynomials used for coding. Must have ``r`` number of
          elements, where the most significant ``k`` bits of each
          element will be used as the polynomial for that index.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.radio.ConvolutionalCodingParams)
  ))
_sym_db.RegisterMessage(ConvolutionalCodingParams)

ScramblingParams = _reflection.GeneratedProtocolMessageType('ScramblingParams', (_message.Message,), dict(
  DESCRIPTOR = _SCRAMBLINGPARAMS,
  __module__ = 'stellarstation.api.v1.radio.radio_pb2'
  ,
  __doc__ = """Parameters for scrambling applied to a bitstream.
  
  
  Attributes:
      type:
          The type of scrambling.
      num_bits:
          The length of the shift register, in bits.
      mask:
          The polynomial mask for the shift register. The most
          significant ``num_bits`` bits of ``mask`` will be used.
      seed:
          The initial contents of the shift register. The most
          significant ``num_bits`` bits of ``mask`` will be used.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.radio.ScramblingParams)
  ))
_sym_db.RegisterMessage(ScramblingParams)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
